This crate provides additional formats for the image crate.
Call the register function at program startup:
image_extras::register();
// Now you can use the image crate as normal
let img = image::open("path/to/image.pcx").unwrap();By default, all supported formats are enabled. For finer control, enable individual formats via Cargo features.
Modules
- ora
- Decoding of OpenRaster Images (*.ora)
- otb
- Decoding of OTB Images
- pcx
- Decoding of PCX Images
- sgi
- Decoding of SGI Image File Format (.rgb)
- wbmp
- Encoding and Decoding of WBMP Images
- xbm
- Decoding of X BitMap (.xbm) Images
- xpm
- Decoding of XPM Images
Functions
- register
- Register all enabled extra formats with the image crate.