pub struct DdsDecoder<R> { /* private fields */ }Expand description
DDS decoder.
This decoder supports decoding DDS files with a single texture, including cube maps. Texture arrays and volumes are not supported.
It’s possible to set the color type the image is decoded as using
DdsDecoder::set_color_type.
Implementations
Sourceimpl<R: Read> DdsDecoder<R>
impl<R: Read> DdsDecoder<R>
Sourcepub fn new(r: R) -> ImageResult<Self>
pub fn new(r: R) -> ImageResult<Self>
Create a new decoder that decodes from the stream r
Sourcepub fn set_color_type(&mut self, color: ColorType) -> ImageResult<()>
pub fn set_color_type(&mut self, color: ColorType) -> ImageResult<()>
Set the color type for the decoder.
The DDS decoder supports decoding images not just in their native color
format, but any user-defined color format. This is useful for decoding
images that do not cleanly fit into the native formats. E.g. the DDS
format B5G6R5_UNORM is decoded as ColorType::Rgb8 by default, but
you may want to decode it as ColorType::Rgb32F instead to avoid the
rounding error when converting to u8. Similarly, your application may
only support 8-bit images, while the DDS file is in a 16/32-bit format.
Decoding directly into the final color type is more efficient than
decoding into the native format and then converting.
Errors
Currently, ColorType::La8 and ColorType::La16 are not supported
for decoding DDS files. If these color types (or other unsupported types)
are provided, this function will return ImageError::Unsupported with
UnsupportedErrorKind::Color.