pub struct IcnsDecoder<R> { /* private fields */ }Expand description
ICNS decoder
Implementations
Sourceimpl<R> IcnsDecoder<R>
impl<R> IcnsDecoder<R>
Sourcepub fn new(reader: R) -> Result<IcnsDecoder<R>, ImageError>
pub fn new(reader: R) -> Result<IcnsDecoder<R>, ImageError>
Create a new IcnsDecoder and seek around the input file to locate
the “best” image. (“best” here means largest, breaking ties to prefer
higher total bit depth; if still tied the earliest image is chosen.)
The resulting decoder does not support decoding Jpeg2000 image entries. Use [IcnsDecoder::new_with_decode_funcs] if you’d like to supply your own function for that.
Sourcepub fn new_with_decode_func(
reader: R,
jp2: SubformatDecodeFn,
) -> Result<IcnsDecoder<R>, ImageError>
pub fn new_with_decode_func( reader: R, jp2: SubformatDecodeFn, ) -> Result<IcnsDecoder<R>, ImageError>
Create a new IcnsDecoder and seek around the input file to locate
the “best” image. (“best” here means largest, breaking ties to prefer
higher total bit depth; if still tied the earliest image is chosen.)
The ICNS format can nest PNG and JP2 images; this function accepts a function that can be used to decode the JP2 images. See for example unsupported_jpeg2000, and decode_jpeg2000_using_hook.