Module ora

Module ora 

Decoding of OpenRaster Images (*.ora)

OpenRaster is an a file format used to communicate layered images; the decoder provided herein only extracts and displays the final merged raster image cached by the OpenRaster file, and does not expose the details of layers (which may be either raster or vector graphics) or render the merged image itself.

Structs

OpenRasterDecoder