Module sgi

Module sgi 

Decoding of SGI Image File Format (.rgb)

The SGI Image File format (often referred to as .rgb) is an obsolete file format which has uncompressed and run-length encoded modes, supports a variable number of color channels, and both 8-bit and 16-bit precisions.

This decoder does not support:

  • Images with ≥ 5 color channels (zsize). (While theoretically supported by the format, we haven’t found any existing images that do this.)

  • Colormaps: Not supported, only the NORMAL=0 mode. The other operations (DITHERED=1, SCREEN=2, COLORMAP=3) were obsolete at the time the spec was written.

The format specification does not explain how the alpha channel is to be interpreted. Existing decoders appear to assume straight alpha, like PNG.

Specification:

Structs

SgiDecoder
Decoder for SGI (.rgb) images.