pub struct OpenRasterDecoder<'a, R>{ /* private fields */ }Implementations
Sourceimpl<'a, R> OpenRasterDecoder<'a, R>
impl<'a, R> OpenRasterDecoder<'a, R>
Sourcepub fn with_limits(
r: R,
limits: Limits,
) -> Result<OpenRasterDecoder<'a, R>, ImageError>
pub fn with_limits( r: R, limits: Limits, ) -> Result<OpenRasterDecoder<'a, R>, ImageError>
Create a new OpenRasterDecoder with the provided limits.
(Limits need to be specified in advance, because determining the minimum information needed for the ImageDecoder trait (image size and color type) may require reading through and remembering image-dependent amount of data.)
Warning: While decoding limits apply to the header parsing and decoding of the merged imaged component (a PNG file inside the ZIP archive that forms an OpenRaster file), memory constraints on the ZIP file decoding process have not yet been implemented; input ZIP files with very many entries may require significant amounts of memory to read.